'''urlp CLI'''


import argparse
import sys
import tldextract

try:
    from urlparse import urlparse
except ImportError:
    from urllib.parse import urlparse


def run_host_command(args, url):
    hostname = urlparse(url).hostname
    print(hostname)


def run_path_command(args, url):
    path = urlparse(url).path
    if args.path_index > -1:
        pathes = path.split('/')
        if len(pathes) < (args.path_index + 1):
            sys.stderr.write('path_index out of range\n')
            exit(1)
        print(pathes[args.path_index+1])
    else:
        print(path)


def run_registered_domain(args, url):
    print(tldextract.extract(url).registered_domain)


def run_default_command(args, url):
    print(url)


commands = {
    'host': run_host_command,
    'path': run_path_command,
    'registered_domain': run_registered_domain,
    'all': run_default_command,
}


def execute(args):
    command = commands[args.part]
    for url in args.input:
        command(args, url)


def execute_from_stdin(args):
    command = commands[args.part]
    for line in sys.stdin:
        url = line.strip()
        command(args, url)


def main():
    '''urlp CLI main command.'''

    parser = argparse.ArgumentParser(
        prog='urlp',
        description='A command line url parser'
    )

    parser.add_argument('input', metavar='url', nargs='*', help='URL to parse')
    parser.add_argument('--part', default='all', choices=commands.keys(),
                        help='Part of URL to show')
    parser.add_argument('--path_index', type=int, default=-1,
                        help='Filter parsed path by index')

    args = parser.parse_args()

    if len(args.input) is 0:
        execute_from_stdin(args)
    else:
        execute(args)




"""A setuptools based setup module.
See:
https://packaging.python.org/guides/distributing-packages-using-setuptools/
https://github.com/pypa/sampleproject
"""


from setuptools import setup, find_packages
from os import path
from io import open

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()


setup(
    name='urlp',
    version='0.0.0',
    description='A simple command-line utility for parsing URLs.',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/yangxuhui/urlp',
    author='Xuhui Yang',
    author_email='yangxuhui1992@163.com', 
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Utilities',
        'License :: OSI Approved :: BSD License',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    keywords='url parse command-line',
    packages=['urlp'],
    python_requires='>=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*, !=3.4.*, <4',
    install_requires=['tldextract'],
    entry_points={
        'console_scripts': [
            'urlp=urlp.cli:main',
        ],
    },
)